==> apache-ambari-2.6.2-src.tar.gz: apache-ambari-2.6.2-src/ambari-server/src/main/java/org/apache/ambari/server/api/resources/ViewInstanceResourceDefinition.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.api.resources;

import org.apache.ambari.server.controller.spi.Resource;

import java.util.HashSet;
import java.util.Set;


/**
 * View instance resource definition.
 */
public class ViewInstanceResourceDefinition extends BaseResourceDefinition {

  /**
   * The parent view name.
   */
  private final Set<SubResourceDefinition> subResourceDefinitions;

  // ----- Constructors ------------------------------------------------------

  /**
   * Construct a view instance resource definition.
   */
  public ViewInstanceResourceDefinition(Set<SubResourceDefinition> subResourceDefinitions) {
    super(Resource.Type.ViewInstance);

    this.subResourceDefinitions = subResourceDefinitions == null ? new HashSet<SubResourceDefinition>() :
        new HashSet<SubResourceDefinition>(subResourceDefinitions);

    this.subResourceDefinitions.add(new SubResourceDefinition(Resource.Type.ViewPrivilege));
  }


  // ----- ResourceDefinition ------------------------------------------------

  @Override
  public String getPluralName() {
    return "instances";
  }

  @Override
  public String getSingularName() {
    return "instance";
  }

  @Override
  public Set<SubResourceDefinition> getSubResourceDefinitions() {
    return subResourceDefinitions;
  }
}

==> apache-ambari-2.7.8-src.tar.gz: apache-ambari-2.7.8-src/ambari-server/src/main/java/org/apache/ambari/server/api/resources/ViewInstanceResourceDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.api.resources;

import java.util.HashSet;
import java.util.Set;

import org.apache.ambari.server.controller.spi.Resource;


/**
 * View instance resource definition.
 */
public class ViewInstanceResourceDefinition extends BaseResourceDefinition {

  /**
   * The parent view name.
   */
  private final Set<SubResourceDefinition> subResourceDefinitions;

  // ----- Constructors ------------------------------------------------------

  /**
   * Construct a view instance resource definition.
   */
  public ViewInstanceResourceDefinition(Set<SubResourceDefinition> subResourceDefinitions) {
    super(Resource.Type.ViewInstance);

    this.subResourceDefinitions = subResourceDefinitions == null ? new HashSet<>() :
      new HashSet<>(subResourceDefinitions);

    this.subResourceDefinitions.add(new SubResourceDefinition(Resource.Type.ViewPrivilege));
  }


  // ----- ResourceDefinition ------------------------------------------------

  @Override
  public String getPluralName() {
    return "instances";
  }

  @Override
  public String getSingularName() {
    return "instance";
  }

  @Override
  public Set<SubResourceDefinition> getSubResourceDefinitions() {
    return subResourceDefinitions;
  }
}
